@@ -3,52 +3,55 @@
 config_load <<'EOF'
 ROBSDDIR="${robsddir}"
 BUILDDIR="${builddir}"
+COMMENT="${comment-path}"
 RELDIR="${bsd-reldir}"
 RELXDIR="${x11-reldir}"
+TAGS="${tags-path}"
+TMPDIR="${tmp-dir}"
 EOF
 
-_tmpdir="${BUILDDIR}/tmp"
-
 if [ -e "${RELXDIR}/SHA256" ]; then
 	cat "${RELXDIR}/SHA256" >>"${RELDIR}/SHA256"
 	rm "${RELXDIR}/SHA256"
 fi
 
-if [ -d "$RELXDIR" ]; then
-	find "$RELXDIR" -type f -exec mv {} "$RELDIR" \;
-	rm -r "$RELXDIR"
+if [ -d "${RELXDIR}" ]; then
+	find "${RELXDIR}" -type f -exec mv {} "${RELDIR}" \;
+	rm -r "${RELXDIR}"
 fi
 
-cd "$RELDIR"
+cd "${RELDIR}"
 
-diff_list "$BUILDDIR" "*.diff" |
+diff_list "${BUILDDIR}" "*.diff" |
 while read -r _f; do
-	cp "$_f" .
+	cp "${_f}" .
 done
 
 {
 	# Set the date to the start of the build.
-	_date="$(build_date -b "$BUILDDIR")"
-	date -u -r "$_date" "+Build date: %s - %+"
+	_date="$(build_date -b "${BUILDDIR}")"
+	date -u -r "${_date}" "+Build date: %s - %+"
 	# Include date of the last CVS revision.
 	for _dir in $(prev_release); do
-		_date="$(cvs_date -b "$BUILDDIR" -s "$(step_path "$_dir")")" || continue
-		date -u -r "$_date" "+Build cvs date: %s - %+"
+		_date="$(cvs_date -b "${BUILDDIR}" -s "$(step_path "${_dir}")")" || continue
+		date -u -r "${_date}" "+Build cvs date: %s - %+"
 		break
 	done
 	echo "Build id: ${BUILDDIR##*/}"
-	if [ -e "${BUILDDIR}/tags" ]; then
+	if [ -e "${TAGS}" ]; then
 		echo -n "Build tags: "
-		xargs <"${BUILDDIR}/tags"
+		xargs <"${TAGS}"
 	fi
 
-	if [ -e "${BUILDDIR}/comment" ]; then
+	if [ -e "${COMMENT}" ]; then
 		echo
-		cat "${BUILDDIR}/comment"
+		cat "${COMMENT}"
 	fi
 } >BUILDINFO
 
-cvs_changelog -t "$_tmpdir" >CHANGELOG
+if step_eval -n cvs "$(step_path "${BUILDDIR}")" 2>/dev/null && ! step_skip; then
+	cvs_changelog -t "${TMPDIR}" >CHANGELOG
+fi
 
 # Compute missing checksums.
 mv SHA256 SHA256.orig
@@ -68,3 +71,7 @@ mv SHA256 SHA256.orig
 	xargs -rt sha256
 } | sort >SHA256
 rm SHA256.orig
+
+cd "${BUILDDIR}"
+mkdir -p snapshots
+(cd snapshots && ln -fs ../rel "$(machine)")
