@@ -6,6 +6,6 @@ RDONLY="${rdonly}"
 BSDSRCDIR="${bsd-srcdir}"
 EOF
 
-[ "$RDONLY" -eq 1 ] || exit 0
+[ "${RDONLY}" -eq 1 ] || exit 0
 
-mount -uw "$BSDSRCDIR"
+mount -uw "${BSDSRCDIR}"
