@@ -281,7 +281,7 @@ cvs_log() {
 	done
 	if [ -z "${_date}" ]; then
 		echo "cvs_log: previous date not found" 1>&2
-		return 0
+		return 1
 	fi
 	_date="$(date -r "${_date}" '+%F %T')"
 
@@ -329,7 +329,7 @@ cvs_log() {
 		cat "${_path}/author"
 		echo "Date: ${_date} ${_time}"
 		echo
-		cat "${_path}/message"
+		vis "${_path}/message"
 		echo
 		cat "${_path}/files"
 		echo
@@ -583,6 +583,34 @@ duration_prev() {
 	return 1
 }
 
+# duration_total_parallel -s steps
+#
+# Calculate the total duration. Since some robsd utilities runs steps in
+# parallel, the accumulated step duration cannot be used. Instead, favor the
+# wall clock delta between the last and first step.
+duration_total_parallel () {
+	local _t0=0
+	local _t1=0
+	local _steps
+
+	while [ $# -gt 0 ]; do
+		case "$1" in
+		-s)	shift; _steps="$1";;
+		*)	break;;
+		esac
+		shift
+	done
+	: "${_steps:?}"
+
+	if step_eval 1 "${_steps}" 2>/dev/null; then
+		_t0="$(step_value time)"
+	fi
+	if step_eval -1 "${_steps}" 2>/dev/null; then
+		_t1="$(step_value time)"
+	fi
+	echo "$((_t1 - _t0))"
+}
+
 # duration_total -s steps
 #
 # Calculate the accumulated build duration.
@@ -602,8 +630,8 @@ duration_total() {
 	: "${_steps:?}"
 
 	case "${_MODE}" in
-	robsd-regress)
-		regress_duration_total -s "${_steps}"
+	canvas|robsd-regress)
+		duration_total_parallel -s "${_steps}"
 		return 0
 		;;
 	*)
@@ -917,7 +945,8 @@ robsd() {
 	_ncpu="$(config_value ncpu)"
 	_steps="$(step_path "${_builddir}")"
 
-	steps -o "${_step}" | while read -r _step _name _parallel; do
+	steps -o "${_step}" |
+	while read -r _step _name _parallel; do
 		if step_eval -n "${_name}" "${_steps}" 2>/dev/null &&
 		   step_skip; then
 			info "step ${_name} skipped"
@@ -946,6 +975,12 @@ robsd() {
 			fi
 
 			if [ "${_name}" = "end" ]; then
+				# Write back the time for the end step after the
+				# barrier above in order to support accurate
+				# duration total calculations.
+				step_write -t -s "${_step}" -n "${_name}" \
+					-e -1 -d -1 "${_steps}"
+
 				# The duration of the end step is the
 				# accumulated duration.
 				_d1="$(duration_total -s "${_steps}")"
@@ -957,8 +992,9 @@ robsd() {
 				fi
 				step_write -t -s "${_step}" -n "${_name}" -e 0 \
 					-d "${_d1}" -a "${_delta}" "${_steps}"
-				# The hook is invoked as late as possible in the
-				# exit trap handler.
+				# Intentionally not calling robsd-hook here as
+				# its invoked as late as possible in the exit
+				# trap handler.
 				return 0
 			fi
 
@@ -1323,7 +1359,8 @@ step_value() {
 
 # trap_exit -r robsd-dir [-b build-dir] [-s stat-pid]
 #
-# Exit trap handler. The build dir may not be present if we failed very early on.
+# Exit trap handler. The build dir may not be present if we failed very early
+# on.
 trap_exit() {
 	local _err="$?"
 	local _builddir=""
